#!/bin/bash
# Filename: build-python3-docs-html.sh
# Automates the packaging process of the software "python-docs" for
# use with Zenwalk Linux.  
# Copyright (C) 2009 Michael Verret michael.verret@gmail.com
# Software source: http://www.python.org/
# Software dependencies: " "

WorkArea=$(pwd)
SoftwareName='python-docs'
SoftwareVersion='2.6.2'
SourceName="python-$SoftwareVersion-docs-html"
CompressionAlgorithm='tar.bz2'
Arch='noarch'
Build='62.1'
Package="$SoftwareName-$SoftwareVersion-$Arch-$Build"
InstallDir="$WorkArea/$Package"
DocDir="$InstallDir/usr/doc/python-$SoftwareVersion/html"
SrcDir="$InstallDir/usr/src/$SoftwareName-$SoftwareVersion"

# Files from previous builds are considered cruft.
Cruft="$SoftwareName-$SoftwareVersion $Package $Package.*"
for Each in ${Cruft} ; do
	if [ -e $Each ] ; then
		rm -rf $Each
	fi
done

tar -xvjf $SourceName.$CompressionAlgorithm

cd $SourceName
chown -R root:root .
find . \
	\( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
	-exec chmod 755 {} \; -o \
	\( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
	-exec chmod 644 {} \;

mkdir -p $DocDir
cp -aR * $DocDir

# Install the icons (using the software "imagemagick"):
mkdir -p $InstallDir/usr/share/icons/hicolor/{16x16,32x32,48x48,64x64,96x96}/apps
convert $WorkArea/python-icon-96x96.png -resize 16x16 \
	$InstallDir/usr/share/icons/hicolor/16x16/apps/python.png
convert $WorkArea/python-icon-96x96.png -resize 32x32 \
	$InstallDir/usr/share/icons/hicolor/32x32/apps/python.png
convert $WorkArea/python-icon-96x96.png -resize 48x48 \
	$InstallDir/usr/share/icons/hicolor/48x48/apps/python.png
convert $WorkArea/python-icon-96x96.png -resize 64x64 \
	$InstallDir/usr/share/icons/hicolor/64x64/apps/python.png
cp $WorkArea/python-icon-96x96.png \
	$InstallDir/usr/share/icons/hicolor/96x96/apps/python.png

# Python documentation launcher:
mkdir -p $InstallDir/usr/share/applications
cat <<EOF0 > $InstallDir/usr/share/applications/python-documentation.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/python-$SoftwareVersion/html/index.html
Icon=python
Type=Application
Categories=Application;Development;
Name=Python Documentation
GenericName=Python Documentation
MimeType=text/html
X-KDE-StartupNotify=true
EOF0

# Python tutorial launcher:
cat <<EOF1 > $InstallDir/usr/share/applications/python-tutorial.desktop
[Desktop Entry]
Encoding=UTF-8
Exec=firefox file:///usr/doc/python-$SoftwareVersion/html/tutorial/index.html
Icon=python
Type=Application
Categories=Application;Development;
Name=Python Tutorial
GenericName=Python Tutorial
MimeType=text/html
X-KDE-StartupNotify=true
EOF1

mkdir -p $InstallDir/install
cat <<EOF2 > $InstallDir/install/slack-desc 
           |-----handy-ruler------------------------------------------------------|
python-docs: python-docs (Python Documentation and Tutorial in html format)
python-docs:
python-docs: Python is an interpreted, interactive, object-oriented
python-docs: programming language that combines remarkable power with
python-docs: very clear syntax. Python's basic power can be extended
python-docs: with your own modules written in C or C++. Python is
python-docs: also adaptable as an extension language for existing
python-docs: applications.
python-docs:
python-docs:
python-docs:
EOF2

mkdir -p $SrcDir
cd $WorkArea ; cp build-$SoftwareName.sh python-icon-96x96.png $SrcDir

cd $InstallDir ; makepkg -l y -c n $InstallDir.tlz
	
cd $WorkArea
	echo "python3" > $Package.dep
	md5sum $Package.tlz > $Package.md5
	rm -rf $SourceName $InstallDir

# CHANGELOG:
# ~ Tue Apr 21 2009	Michael Verret "axxium" michael.verret@gmail.com
# ~ Software python-docs-html 2.6.2
